==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersThreatIntelIndicatorLastObservedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersThreatIntelIndicatorLastObservedAtArgs(
    public val dateRange: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>? =
        null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs> {
    override fun toJava():
        com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersThreatIntelIndicatorLastObservedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersThreatIntelIndicatorLastObservedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>? =
        null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("kfxnpeyjyokcyhtr")
    public suspend
    fun dateRange(`value`: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("flukrimosgoyctof")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("kukytpsxkxjfmisa")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("ysgxtcikuwdkdhbr")
    public suspend
    fun dateRange(`value`: InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("mbagcxxvavwhissn")
    public suspend
    fun dateRange(argument: suspend InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped =
            InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("itacbjilbbxiadhd")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("fixkjlgkwlvjewrp")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersThreatIntelIndicatorLastObservedAtArgs =
        InsightFiltersThreatIntelIndicatorLastObservedAtArgs(
            dateRange = dateRange,
            end = end,
            start = start,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersThreatIntelIndicatorLastObservedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersThreatIntelIndicatorLastObservedAtArgs(
    public val dateRange: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>? =
        null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersThreatIntelIndicatorLastObservedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersThreatIntelIndicatorLastObservedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersThreatIntelIndicatorLastObservedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>? =
        null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("dwfrqvymskrughvw")
    public suspend fun dateRange(`value`: Output<InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("mtiwevptjathrrvy")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("sfxobhtrkanqlfjs")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("ptnjdxdnwlaebhgc")
    public suspend fun dateRange(`value`: InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("uhlakabvmqfmxcok")
    public suspend fun dateRange(argument: suspend InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped =
            InsightFiltersThreatIntelIndicatorLastObservedAtDateRangeArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("qhtpfrpwswaahobh")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("mogiapvervdcinim")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersThreatIntelIndicatorLastObservedAtArgs =
        InsightFiltersThreatIntelIndicatorLastObservedAtArgs(
            dateRange = dateRange,
            end = end,
            start = start,
        )
}
